@@ -32,6 +32,9 @@ AccountSettingsDialog::AccountSettingsDialog(QWidget* parent /* = 0 */)
 , ui(new Ui_AccountSettingsDialog)
 {
   ui->setupUi(this);
+
+  // Try not to start with uppercase
+  ui->usernameEdit->setInputMethodHints(Qt::ImhNoAutoUppercase);
 }
 
 //////////////////////////////////////////////////////////////////////////
