@@ -244,7 +244,7 @@ void Betamax::sendMessage(const Message& message)
 
   QString toField = numbers.join("\n");
 
-  QByteArray text = toUrlPercentEncoding(message.text().toLocal8Bit());
+  QByteArray text = toUrlPercentEncoding(toLatin1Euro(message.text()));
 
   // Setup the message
   // sendsms.php?username=xxxxxxxxxx?&password=xxxxxxxxxx&from=xxxxxxxxxx&to=xxxxxxxxxx&text=xxxxxxxxxx
