@@ -30,6 +30,10 @@
 #include <QtCore/QDebug> 
 #include <QtCore/QDataStream>
 #include <QtCore/QFile>
+#include <QtCore/QTimer>
+#include <QtGui/QLabel>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QDialogButtonBox>
 #include <QtNetwork/QNetworkAccessManager>
 #include <QtNetwork/QNetworkRequest>
 #include <QtNetwork/QNetworkReply>
@@ -38,6 +42,110 @@
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
 
+class o2GermanySendStateDialog : public QDialog
+{
+  Q_OBJECT
+
+public:
+  o2GermanySendStateDialog(QWidget* parent = 0, Qt::WindowFlags f = 0);
+  ~o2GermanySendStateDialog();
+
+  void setState(int state);
+
+  QDialogButtonBox buttonBox;
+  QLabel label;
+
+  Message message;
+  QString messageId;
+
+  QObject* privClass;
+};
+
+//////////////////////////////////////////////////////////////////////////
+
+o2GermanySendStateDialog::o2GermanySendStateDialog(QWidget* parent /* = 0 */, Qt::WindowFlags f /* = 0 */)
+: QDialog(parent, f)
+, buttonBox(this)
+{
+  setWindowTitle( tr("Delivery state") );
+
+  buttonBox.setOrientation(Qt::Vertical);
+  buttonBox.setStandardButtons(QDialogButtonBox::Close);
+
+  QHBoxLayout* layout = new QHBoxLayout;
+  layout->addWidget(&label);
+  layout->addWidget(&buttonBox);
+  setLayout(layout);
+
+  connect(&buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+  connect(&buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+}
+
+//////////////////////////////////////////////////////////////////////////
+
+o2GermanySendStateDialog::~o2GermanySendStateDialog()
+{
+}
+
+//////////////////////////////////////////////////////////////////////////
+
+void o2GermanySendStateDialog::setState(int state)
+{
+  QString text;
+
+  switch(state)
+  {
+  case 0:
+    text = tr("Awaiting information ...");
+    break;
+
+  case 1: // DeliveryPending
+    text = tr("Waiting for receipt");
+    break;
+
+  case 2: // Delivered
+    text = tr("Delivered");
+    break;
+
+  case 3: // ReceiptConfirmed
+    text = tr("Receipt confirmed");
+    break;
+
+  case 4: // NotDelivered
+    text = tr("Not yet delivered");
+    break;
+
+  case 5: // NotAdmitted
+    text = tr("Not admitted");
+    break;
+
+  case 6: // InsuffBalance
+    text = tr("Insufficient balance");
+    break;
+
+  case 7: // DeliveredPartly
+    text = tr("Partially delivered");
+    break;
+
+  default:
+    text = tr("Unknown");
+    break;
+  }
+
+  label.setText(text);
+
+  if ( state != 5 && state != 2 && state != 0 )
+    QTimer::singleShot(5000, privClass, SLOT(updateSendDetails()));
+
+#ifdef Q_WS_MAEMO_5
+  setAttribute(Qt::WA_Maemo5ShowProgressIndicator, state != 5 && state != 2);
+#endif // Q_WS_MAEMO_5
+}
+
+//////////////////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////
+
 class o2GermanyPrivate : public QObject
 {
   Q_OBJECT
@@ -47,6 +155,8 @@ public:
   : sentMessages(0)
   , freeSMSCount(-1)
   {
+    sendStateDialog.privClass = this;
+
     // We define some default urls (may be replaced by code later)
     urls.preLoginUrl      = QUrl("http://www.o2online.de");
     urls.logoutUrl        = QUrl("https://login.o2online.de/loginRegistration/loginAction.do?_flowId=logout");
@@ -65,12 +175,15 @@ public:
     Logout,
     ComCenter,
     SmsCenter,
-    SmsCenterSend
+    SmsCenterSend,
+    FolderSent
   };
 
   o2Germany* self;
 
   // Properties
+  o2GermanySendStateDialog sendStateDialog;
+
   QNetworkAccessManager accessManager;
 
   struct
@@ -82,6 +195,8 @@ public:
     QUrl comCenterUrl;
     QUrl smsCenterUrl;
     QUrl smsCenterSendUrl;
+
+    QUrl folderSentUrl;
   } urls;
 
   QHash<QNetworkReply*, State> replyStateHash;
@@ -90,6 +205,8 @@ public:
   QString loginName;
   QString password;
 
+  QString sessionId;
+
   int sentMessages;
   int freeSMSCount;
 
@@ -97,7 +214,7 @@ public:
 
   // Functions
   QNetworkRequest prepareRequest() const;
-  
+
   // Network functions
   QNetworkReply* get(const QNetworkRequest& request, State state);
   QNetworkReply* post(const QNetworkRequest& request, const QByteArray& data, State state);
@@ -109,9 +226,11 @@ public:
   void handleSmsCenter(QNetworkReply* reply);
   void handleSmsCenterSend(QNetworkReply* reply);
   void handleLogout(QNetworkReply* reply);
+  void handleFolderSent(QNetworkReply* reply);
 
 public slots:
   void onReplyFinished(QNetworkReply* reply);
+  void updateSendDetails();
 };
 
 //////////////////////////////////////////////////////////////////////////
@@ -130,6 +249,7 @@ QNetworkReply* o2GermanyPrivate::get(const QNetworkRequest& request, State state
 {
   // Get the request
   QNetworkReply* reply = accessManager.get(request);
+  reply->ignoreSslErrors();
 
   // Remember the reply with the given state
   replyStateHash.insert(reply, state);
@@ -143,6 +263,7 @@ QNetworkReply* o2GermanyPrivate::post(const QNetworkRequest& request, const QByt
 {
   // Get the post
   QNetworkReply* reply = accessManager.post(request, data);
+  reply->ignoreSslErrors();
 
   // Remember the reply with the given state
   replyStateHash.insert(reply, state);
@@ -274,7 +395,17 @@ void o2GermanyPrivate::handleSmsCenter(QNetworkReply* reply)
     int pos = fieldExp.indexIn(data, offset);
     while ( pos != -1 )
     {
-      sendFormDefaultValues.insert( fieldExp.cap(1), fieldExp.cap(2).toUtf8().toPercentEncoding() );
+      // Get the field name
+      const QString fieldName = fieldExp.cap(1);
+
+      // Update the folder urls
+      if ( fieldName == "SID" )
+      {
+        sessionId = fieldExp.cap(2);
+        urls.folderSentUrl = QString("https://email.o2online.de/smscenter_search.osp?SID=%1&FolderID=0").arg(fieldExp.cap(2));
+      }
+
+      sendFormDefaultValues.insert( fieldName, fieldExp.cap(2).toUtf8().toPercentEncoding() );
       
       // Find the next entry
       pos = fieldExp.indexIn(data, pos+fieldExp.matchedLength());
@@ -312,16 +443,30 @@ void o2GermanyPrivate::handleSmsCenterSend(QNetworkReply* reply)
   // Emit a signal that we've sent the message
   emit self->sendMessageReply(true, message);
 
-  // We dome some dummy analysis of the message ...
+  // We do some dummy analysis of the message ...
   MessageType messageType = message.messageType();
   QString messageText = message.text();
 
-  int usedMessageCount = (messageText.size() / messageType.singleMessageLength()) + 1;
+  int usedMessageCount = 0;
+  if ( messageText.size() <= 160 )
+    usedMessageCount = 1;
+  else
+    usedMessageCount = (messageText.size() / messageType.singleMessageLength()) + 1;
 
   // Subtract ...
-  freeSMSCount -= usedMessageCount;
+  freeSMSCount -= usedMessageCount * message.receivers().size();
 
   emit self->balanceReply( tr("%n* free SMS", "", freeSMSCount) );
+
+  // Now we check the send state
+  QNetworkRequest request = prepareRequest();
+  request.setRawHeader("Referer", reply->url().toEncoded());
+  request.setUrl( urls.folderSentUrl );
+  get(request, FolderSent);
+
+  sendStateDialog.message = message;
+  sendStateDialog.setState(0);
+  sendStateDialog.show();
 }
 
 //////////////////////////////////////////////////////////////////////////
@@ -339,6 +484,45 @@ void o2GermanyPrivate::handleLogout(QNetworkReply* reply)
 
 //////////////////////////////////////////////////////////////////////////
 
+void o2GermanyPrivate::handleFolderSent(QNetworkReply* reply)
+{
+  // Get all data from the reply
+  QByteArray readData = reply->readAll();
+  QString data = QString::fromUtf8(readData.constData(), readData.size());
+
+  if ( !sendStateDialog.isVisible() )
+    return;
+
+  int state = -1;
+
+  // Find the message id of the last message (first being found)
+  QRegExp statusExp("displaySendStatus\\((\\d),'(\\d*)'");
+  if ( statusExp.indexIn(data) == -1 )
+  {
+    // Second try
+    statusExp.setPattern( "displaySendStatus\\((\\d)," );
+    if ( statusExp.indexIn(data) == -1 )
+      return;
+  }
+
+  state = statusExp.cap(1).toInt();
+  sendStateDialog.messageId = statusExp.cap(2);
+  sendStateDialog.setState(state);
+}
+
+//////////////////////////////////////////////////////////////////////////
+
+void o2GermanyPrivate::updateSendDetails()
+{
+  QUrl url( QString("https://email.o2online.de/smscenter_group_status.osp?SID=%1&SortColumnType=Field&SortOrder=ASC&SortColumn=RECIPIENT&MsgContentID=%2").arg(sessionId).arg(sendStateDialog.messageId) );
+
+  QNetworkRequest request = prepareRequest();
+  request.setUrl(url);
+  get(request, FolderSent);
+}
+
+//////////////////////////////////////////////////////////////////////////
+
 void o2GermanyPrivate::onReplyFinished(QNetworkReply* reply)
 {
   // Handle a redirection if needed
@@ -388,6 +572,10 @@ void o2GermanyPrivate::onReplyFinished(QNetworkReply* reply)
     handleLogout(reply);
     break;
 
+  case FolderSent:
+    handleFolderSent(reply);
+    break;
+
   default:
     break;
   }
