@@ -49,18 +49,18 @@ public:
   QByteArray saveSettings() const;
 
   bool showAccountSettingsDialog(QWidget* parent);
-  QList<QAction*> actions() const;
 
-  bool hasLoginData() const;
   bool isLoggedIn() const;
 
-  int freeSMSCount() const;
-
-  void login();
-  void logout();
+  CallbackType login();
+  CallbackType logout();
 
   /// SendMessage returns a unique message id for this instance
-  int sendMessage(const QList<ContactInfo>& receivers, const QString& text);
+  void sendMessage(const Message& message);
+
+  void updateBalance();
+
+  QList<MessageType> messageTypes() const;
 
 private:
   o2GermanyPrivate* d;
