@@ -229,7 +229,7 @@ void Sloono::sendMessage(const Message& message)
   foreach(const ContactInfo& contact, message.receivers())
     numbers.append(contact.number());
 
-  QByteArray text = toUrlPercentEncoding( message.text().toLocal8Bit() );
+  QByteArray text = toUrlPercentEncoding( toLatin1Euro(message.text()) );
 
   // Setup the message
   QUrl url("https://www.sloono.de/API/httpsms.php");
