@@ -216,7 +216,7 @@ void sms77de::sendMessage(const Message& message)
   QString number = contact.number();
   number.replace(QRegExp("^\\+"), "00");
 
-  QByteArray text = toUrlPercentEncoding(message.text().toLocal8Bit());
+  QByteArray text = toUrlPercentEncoding( toLatin1Euro(message.text()) );
 
   // Setup the message
   QUrl url("https://gateway.sms77.de");
